@@ -1,21 +1,22 @@
 {-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE CPP #-}
 import Test.HUnit hiding (Test)
-import Test.Hspec.Monadic
-import Test.Hspec.HUnit ()
+import Test.Hspec
 
 import Yesod.Test.CssQuery
 import Yesod.Test.TransversingCSS
-import Yesod.Test.HtmlParse
 import Text.XML
 
 import Data.ByteString.Lazy.Char8 ()
+import qualified Data.Map as Map
+import qualified Text.HTML.DOM as HD
 
 parseQuery_ = either error id . parseQuery
 findBySelector_ x = either error id . findBySelector x
-parseHtml_ = either error id . parseHtml
+parseHtml_ = HD.parseLBS
 
 main :: IO ()
-main = hspecX $ do
+main = hspec $ do
     describe "CSS selector parsing" $ do
         it "elements" $ parseQuery_ "strong" @?= [[DeepChildren [ByTagName "strong"]]]
         it "child elements" $ parseQuery_ "strong > i" @?= [[DeepChildren [ByTagName "strong"], DirectChildren [ByTagName "i"]]]
@@ -33,13 +34,13 @@ main = hspecX $ do
         it "XHTML" $
             let html = "<html><head><title>foo</title></head><body><p>Hello World</p></body></html>"
                 doc = Document (Prologue [] Nothing []) root []
-                root = Element "html" []
-                    [ NodeElement $ Element "head" []
-                        [ NodeElement $ Element "title" []
+                root = Element "html" Map.empty
+                    [ NodeElement $ Element "head" Map.empty
+                        [ NodeElement $ Element "title" Map.empty
                             [NodeContent "foo"]
                         ]
-                    , NodeElement $ Element "body" []
-                        [ NodeElement $ Element "p" []
+                    , NodeElement $ Element "body" Map.empty
+                        [ NodeElement $ Element "p" Map.empty
                             [NodeContent "Hello World"]
                         ]
                     ]
@@ -47,14 +48,14 @@ main = hspecX $ do
         it "HTML" $
             let html = "<html><head><title>foo</title></head><body><br><p>Hello World</p></body></html>"
                 doc = Document (Prologue [] Nothing []) root []
-                root = Element "html" []
-                    [ NodeElement $ Element "head" []
-                        [ NodeElement $ Element "title" []
+                root = Element "html" Map.empty
+                    [ NodeElement $ Element "head" Map.empty
+                        [ NodeElement $ Element "title" Map.empty
                             [NodeContent "foo"]
                         ]
-                    , NodeElement $ Element "body" []
-                        [ NodeElement $ Element "br" [] []
-                        , NodeElement $ Element "p" []
+                    , NodeElement $ Element "body" Map.empty
+                        [ NodeElement $ Element "br" Map.empty []
+                        , NodeElement $ Element "p" Map.empty
                             [NodeContent "Hello World"]
                         ]
                     ]
